@@ -35,6 +35,7 @@ extern zend_module_entry libxml_module_entry;
 
 #include "zend_smart_str.h"
 #include <libxml/tree.h>
+#include <libxml/parser.h>
 
 #define LIBXML_SAVE_NOEMPTYTAG 1<<2
 
@@ -43,8 +44,8 @@ ZEND_BEGIN_MODULE_GLOBALS(libxml)
 	smart_str error_buffer;
 	zend_llist *error_list;
 	struct _php_libxml_entity_resolver {
-		zval                    object;
-		zend_fcall_info			fci;
+		zval 					callback;
+		zend_fcall_info 		fci;
 		zend_fcall_info_cache	fcc;
 	} entity_loader;
 	bool entity_loader_disabled;
@@ -118,12 +119,30 @@ PHP_LIBXML_API void php_libxml_shutdown(void);
 ZEND_TSRMLS_CACHE_EXTERN()
 #endif
 
+#if defined(__clang__)
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_START \
+	_Pragma("clang diagnostic push") \
+	_Pragma("clang diagnostic ignored \"-Wdeprecated-declarations\"")
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_END \
+	_Pragma("clang diagnostic pop")
+#elif defined(__GNUC__)
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_START \
+	_Pragma("GCC diagnostic push") \
+	_Pragma("GCC diagnostic ignored \"-Wdeprecated-declarations\"")
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_END \
+	_Pragma("GCC diagnostic pop")
+#else
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_START
+# define PHP_LIBXML_IGNORE_DEPRECATIONS_END
+#endif
+
 /* Other extension may override the global state options, these global options
  * are copied initially to ctxt->options. Set the options to a known good value.
  * See libxml2 globals.c and parserInternals.c.
  * The unique_name argument allows multiple sanitizes and restores within the
  * same function, even nested is necessary. */
 #define PHP_LIBXML_SANITIZE_GLOBALS(unique_name) \
+	PHP_LIBXML_IGNORE_DEPRECATIONS_START \
 	int xml_old_loadsubset_##unique_name = xmlLoadExtDtdDefaultValue; \
 	xmlLoadExtDtdDefaultValue = 0; \
 	int xml_old_validate_##unique_name = xmlDoValidityCheckingDefaultValue; \
@@ -131,15 +150,18 @@ ZEND_TSRMLS_CACHE_EXTERN()
 	int xml_old_pedantic_##unique_name = xmlPedanticParserDefault(0); \
 	int xml_old_substitute_##unique_name = xmlSubstituteEntitiesDefault(0); \
 	int xml_old_linenrs_##unique_name = xmlLineNumbersDefault(0); \
-	int xml_old_blanks_##unique_name = xmlKeepBlanksDefault(1);
+	int xml_old_blanks_##unique_name = xmlKeepBlanksDefault(1); \
+	PHP_LIBXML_IGNORE_DEPRECATIONS_END
 
 #define PHP_LIBXML_RESTORE_GLOBALS(unique_name) \
+	PHP_LIBXML_IGNORE_DEPRECATIONS_START \
 	xmlLoadExtDtdDefaultValue = xml_old_loadsubset_##unique_name; \
 	xmlDoValidityCheckingDefaultValue = xml_old_validate_##unique_name; \
 	(void) xmlPedanticParserDefault(xml_old_pedantic_##unique_name); \
 	(void) xmlSubstituteEntitiesDefault(xml_old_substitute_##unique_name); \
 	(void) xmlLineNumbersDefault(xml_old_linenrs_##unique_name); \
-	(void) xmlKeepBlanksDefault(xml_old_blanks_##unique_name);
+	(void) xmlKeepBlanksDefault(xml_old_blanks_##unique_name); \
+	PHP_LIBXML_IGNORE_DEPRECATIONS_END
 
 /* Alternative for above, working directly on the context and not setting globals.
  * Generally faster because no locking is involved, and this has the advantage that it sets the options to a known good value. */
